@@ -1,6 +1,6 @@
 package DBIx::DBO;
 
-use 5.010;
+use 5.008;
 use strict;
 use warnings;
 use DBI;
@@ -9,13 +9,17 @@ use DBIx::DBO::Table;
 use DBIx::DBO::Query;
 use DBIx::DBO::Row;
 
+# The C3 method resolution order is needed for optimal functioning when DBIx::DBO is being subclassed.
+my $mro_c3 = $] >= 5.009_005 || eval {require MRO::Compat};
+my $c3_initialize;
+
 =head1 NAME
 
 DBIx::DBO - An OO interface to SQL queries and results.  Easily constructs SQL queries, and simplifies processing of the returned data.
 
 =cut
 
-our $VERSION = '0.01_03';
+our $VERSION = '0.02_01';
 
 =head1 SYNOPSIS
 
@@ -60,9 +64,9 @@ our $VERSION = '0.01_03';
 
 This module provides a convenient and efficient way to access a database. It can construct queries for you and returns the results in easy to use methods.
 
-Once you've created a C<DBIx::DBO> object using one or both of C<connect> or C<connect_readonly>, you can begin creating C<DBIx::DBO::Query> objects. These are the "workhorse" objects, they encapsulate an entire query with JOINs, WHERE clauses, etc. You need not have to know about what created the Query to be able to use or modify it. This makes it valuable in environments like mod_perl or large projects that prefer an object oreinted approach to data.
+Once you've created a C<DBIx::DBO> object using one or both of C<connect> or C<connect_readonly>, you can begin creating C<DBIx::DBO::Query> objects. These are the "workhorse" objects, they encapsulate an entire query with JOINs, WHERE clauses, etc. You need not have to know about what created the C<Query> to be able to use or modify it. This makes it valuable in environments like mod_perl or large projects that prefer an object oreinted approach to data.
 
-The Query is only automatically executed when the data is requested. This is to make it possible to minimise lookups that may not be needed or to delay them as late as possible.
+The query is only automatically executed when the data is requested. This is to make it possible to minimise lookups that may not be needed or to delay them as late as possible.
 
 The C<DBIx::DBO::Row> object returned can be treated as both an arrayref or a hashref. The data is aliased for efficient use of memory. C<Row> objects can be updated or deleted, even when created by JOINs (If the DB supports it).
 
@@ -120,6 +124,7 @@ sub connect {
         $new->{dbh}->set_err('', $@);
         return;
     }
+    Class::C3::initialize() if $c3_initialize;
     $class->_bless_dbo($new);
 }
 
@@ -138,6 +143,7 @@ sub connect_readonly {
         $new->{rdbh}->set_err('', $@);
         return;
     }
+    Class::C3::initialize() if $c3_initialize;
     $class->_bless_dbo($new);
 }
 
@@ -211,6 +217,8 @@ sub _set_inheritance {
     my $class = $me.'::DBD::'.$dbd;
 
     no strict 'refs';
+    return $class if "@{$class.'::Common::ISA'}" eq $me.'::Common';
+
     @{$class.'::Common::ISA'} = ($me.'::Common');
     @{$class.'::ISA'} = ($me, $class.'::Common');
     @{$class.'::'.$_.'::ISA'} = ($me.'::'.$_, $class.'::Common') for qw(Table Query Row);
@@ -220,6 +228,12 @@ sub _set_inheritance {
         eval "package ${me}";
         eval "package ${me}::$_" for qw(Common Table Query Row);
     }
+    if ($mro_c3) {
+        mro::set_mro($class, 'c3');
+        mro::set_mro($class.'::'.$_, 'c3') for qw(Table Query Row);
+        # If perl < 5.9.5 then we need to call Class::C3::initialize()
+        $c3_initialize = $] < 5.009_005;
+    }
     return $class;
 }
 
@@ -243,7 +257,7 @@ The read-only C<DBI> handle, or if there is no read-only connection, the read-wr
   $dbo->do($statement, \%attr) or die $dbo->dbh->errstr;
   $dbo->do($statement, \%attr, @bind_values) or die ...
 
-This provides access to L<DBI-E<gt>do|DBI/"do"> method. It defaults to using the read-write C<DBI> handle.
+This provides access to the L<DBI-E<gt>do|DBI/"do"> method. It defaults to using the read-write C<DBI> handle.
 
 =cut
 
@@ -265,19 +279,19 @@ sub rdbh {
 
   $dbo->selectrow_array($statement, \%attr, @bind_values);
 
-This provides access to L<DBI-E<gt>selectrow_array|DBI/"selectrow_array"> method.
+This provides access to the L<DBI-E<gt>selectrow_array|DBI/"selectrow_array"> method.
 
 =head2 selectrow_arrayref
 
   $dbo->selectrow_arrayref($statement, \%attr, @bind_values);
 
-This provides access to L<DBI-E<gt>selectrow_arrayref|DBI/"selectrow_arrayref"> method.
+This provides access to the L<DBI-E<gt>selectrow_arrayref|DBI/"selectrow_arrayref"> method.
 
 =head2 selectall_arrayref
 
   $dbo->selectall_arrayref($statement, \%attr, @bind_values);
 
-This provides access to L<DBI-E<gt>selectall_arrayref|DBI/"selectall_arrayref"> method.
+This provides access to the L<DBI-E<gt>selectall_arrayref|DBI/"selectall_arrayref"> method.
 
 =cut
 
@@ -305,7 +319,7 @@ sub selectall_arrayref {
   $dbo->table_info([$schema, $table]);
   $dbo->table_info($table_object);
 
-Returns a hashref of PrimaryKeys and Column_Idx for the table.
+Returns a hashref containing C<PrimaryKeys>, C<Columns> and C<Column_Idx> for the table.
 Mainly for internal use.
 
 =cut
@@ -344,7 +358,7 @@ sub _get_table_info {
     if (my $keys = $me->rdbh->primary_key_info(undef, $schema, $table)) {
         $h{PrimaryKeys}[$_->{KEY_SEQ} - 1] = $_->{COLUMN_NAME} for @{$keys->fetchall_arrayref({})};
     }
-    $me->{TableInfo}{$schema // ''}{$table} = \%h;
+    $me->{TableInfo}{defined $schema ? $schema : ''}{$table} = \%h;
 }
 
 sub table_info {
@@ -361,11 +375,11 @@ sub table_info {
             # TODO: Better splitting of: schema.table or `schema`.`table` or "schema"."table"@"catalog" or ...
             ($schema, $table) = split /\./, $table, 2;
         }
-        $schema //= $me->_get_table_schema($schema, $table);
+        defined $schema or $schema = $me->_get_table_schema($schema, $table);
 
-        $me->_get_table_info($schema, $table) unless exists $me->{TableInfo}{$schema // ''}{$table};
+        $me->_get_table_info($schema, $table) unless exists $me->{TableInfo}{defined $schema ? $schema : ''}{$table};
     }
-    return ($schema, $table, $me->{TableInfo}{$schema // ''}{$table});
+    return ($schema, $table, $me->{TableInfo}{defined $schema ? $schema : ''}{$table});
 }
 
 =head2 table
@@ -448,13 +462,17 @@ Get or set the global or C<DBIx::DBO> config settings.
 When setting an option, the previous value is returned.
 
 Options include:
+
 =over
-=item QuoteIdentifier
+
+=item C<QuoteIdentifier>
 Boolean setting to control quoting of SQL identifiers (schema, table and column names).
 Defaults to 1.
-=item _Debug_SQL
+
+=item C<_Debug_SQL>
 Set to a number 0 - 2 to warn with varying levels of debugging for each SQL command executed.
 Defaults to 0.
+
 =back
 
 Global options can also be set when C<use>'ing the module:
@@ -471,7 +489,7 @@ sub config {
         $Config{$opt} = shift if @_;
         return $val;
     }
-    my $val = $me->{Config}{$opt} // $Config{$opt};
+    my $val = defined $me->{Config}{$opt} ? $me->{Config}{$opt} : $Config{$opt};
     $me->{Config}{$opt} = shift if @_;
     return $val;
 }
@@ -523,7 +541,7 @@ This package is free software; you can redistribute it and/or modify it under th
 
 =head1 SEE ALSO
 
-DBI, DBIx::SearchBuilder.
+L<DBI>, DBIx::SearchBuilder.
 
 
 =cut
